summaryrefslogtreecommitdiff
path: root/embeddedobj
diff options
context:
space:
mode:
Diffstat (limited to 'embeddedobj')
-rw-r--r--embeddedobj/source/commonembedding/persistence.cxx8
-rw-r--r--embeddedobj/source/general/dummyobject.cxx2
-rw-r--r--embeddedobj/source/inc/commonembobj.hxx4
-rw-r--r--embeddedobj/source/msole/olecomponent.cxx10
-rw-r--r--embeddedobj/source/msole/oleembed.cxx2
-rw-r--r--embeddedobj/source/msole/olepersist.cxx6
-rw-r--r--embeddedobj/test/Container1/EmbedContApp.java4
-rw-r--r--embeddedobj/test/Container1/NativeView.java12
-rw-r--r--embeddedobj/test/MainThreadExecutor/xexecutor.cxx2
9 files changed, 25 insertions, 25 deletions
diff --git a/embeddedobj/source/general/dummyobject.cxx b/embeddedobj/source/general/dummyobject.cxx
index b63b6435013c..1ea683513736 100644
--- a/embeddedobj/source/general/dummyobject.cxx
+++ b/embeddedobj/source/general/dummyobject.cxx
@@ -330,7 +330,7 @@ void SAL_CALL ODummyEmbeddedObject::setPersistentEntry(
&& ( m_nObjectState == -1 || nEntryConnectionMode != embed::EntryInitModes::NO_INIT ) )
{
throw embed::WrongStateException(
- ::rtl::OUString::createFromAscii( "Can't change persistant representation of activated object!\n" ),
+ ::rtl::OUString::createFromAscii( "Can't change persistent representation of activated object!\n" ),
uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
}
diff --git a/embeddedobj/source/inc/commonembobj.hxx b/embeddedobj/source/inc/commonembobj.hxx
index c23542272afe..29c024ee981f 100644
--- a/embeddedobj/source/inc/commonembobj.hxx
+++ b/embeddedobj/source/inc/commonembobj.hxx
@@ -100,7 +100,7 @@ protected:
sal_Bool m_bClosed;
sal_Int32 m_nObjectState;
- sal_Int32 m_nTargetState; // should be -1 exept during state changing
+ sal_Int32 m_nTargetState; // should be -1 except during state changing
sal_Int32 m_nUpdateMode;
::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory > m_xFactory;
@@ -239,7 +239,7 @@ public:
const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory >& xFactory,
const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& aObjectProps );
- // no persistance for linked objects, so the descriptors are provided in constructor
+ // no persistence for linked objects, so the descriptors are provided in constructor
OCommonEmbeddedObject(
const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory >& xFactory,
const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& aObjectProps,
diff --git a/embeddedobj/source/msole/olecomponent.cxx b/embeddedobj/source/msole/olecomponent.cxx
index c8540951abf3..46b33eec2f1f 100644
--- a/embeddedobj/source/msole/olecomponent.cxx
+++ b/embeddedobj/source/msole/olecomponent.cxx
@@ -268,7 +268,7 @@ HRESULT OpenIStorageFromURL_Impl( const ::rtl::OUString& aURL, IStorage** ppISto
::rtl::OUString aFilePath;
if ( !ppIStorage || ::osl::FileBase::getSystemPathFromFileURL( aURL, aFilePath ) != ::osl::FileBase::E_None )
- throw uno::RuntimeException(); // TODO: something dangerous happend
+ throw uno::RuntimeException(); // TODO: something dangerous happened
return StgOpenStorage( reinterpret_cast<LPCWSTR>(aFilePath.getStr()),
NULL,
@@ -574,7 +574,7 @@ void OleComponent::CreateNewIStorage_Impl()
// open an IStorage based on the temporary file
::rtl::OUString aTempFilePath;
if ( ::osl::FileBase::getSystemPathFromFileURL( aTempURL, aTempFilePath ) != ::osl::FileBase::E_None )
- throw uno::RuntimeException(); // TODO: something dangerous happend
+ throw uno::RuntimeException(); // TODO: something dangerous happened
HRESULT hr = StgCreateDocfile( reinterpret_cast<LPCWSTR>(aTempFilePath.getStr()), STGM_CREATE | STGM_READWRITE | STGM_TRANSACTED | STGM_DELETEONRELEASE, 0, &m_pNativeImpl->m_pIStorage );
if ( FAILED( hr ) || !m_pNativeImpl->m_pIStorage )
@@ -675,7 +675,7 @@ sal_Bool OleComponent::InitializeObject_Impl()
if ( FAILED( hr ) || !m_pNativeImpl->m_pViewObject2 )
return sal_False;
- // not realy needed for now, since object is updated on saving
+ // not really needed for now, since object is updated on saving
// m_pNativeImpl->m_pViewObject2->SetAdvise( DVASPECT_CONTENT, 0, m_pImplAdviseSink );
// remove all the caches
@@ -846,7 +846,7 @@ void OleComponent::CreateObjectFromFile( const ::rtl::OUString& aFileURL )
::rtl::OUString aFilePath;
if ( ::osl::FileBase::getSystemPathFromFileURL( aFileURL, aFilePath ) != ::osl::FileBase::E_None )
- throw uno::RuntimeException(); // TODO: something dangerous happend
+ throw uno::RuntimeException(); // TODO: something dangerous happened
HRESULT hr = OleCreateFromFile( CLSID_NULL,
reinterpret_cast<LPCWSTR>(aFilePath.getStr()),
@@ -876,7 +876,7 @@ void OleComponent::CreateLinkFromFile( const ::rtl::OUString& aFileURL )
::rtl::OUString aFilePath;
if ( ::osl::FileBase::getSystemPathFromFileURL( aFileURL, aFilePath ) != ::osl::FileBase::E_None )
- throw uno::RuntimeException(); // TODO: something dangerous happend
+ throw uno::RuntimeException(); // TODO: something dangerous happened
HRESULT hr = OleCreateLinkToFile( reinterpret_cast<LPCWSTR>(aFilePath.getStr()),
IID_IUnknown,
diff --git a/embeddedobj/source/msole/oleembed.cxx b/embeddedobj/source/msole/oleembed.cxx
index cf6b01ca98b0..31b927a833e2 100644
--- a/embeddedobj/source/msole/oleembed.cxx
+++ b/embeddedobj/source/msole/oleembed.cxx
@@ -398,7 +398,7 @@ sal_Bool OleEmbeddedObject::TryToConvertToOOo()
close( sal_True );
} catch( uno::Exception& ) {}
- m_xParentStorage->dispose(); // ??? the storage has information loss, it should be closed without commiting!
+ m_xParentStorage->dispose(); // ??? the storage has information loss, it should be closed without committing!
throw uno::RuntimeException(); // the repairing is not possible
}
case 2:
diff --git a/embeddedobj/test/Container1/EmbedContApp.java b/embeddedobj/test/Container1/EmbedContApp.java
index 53b42d0270d1..764a33c815a6 100644
--- a/embeddedobj/test/Container1/EmbedContApp.java
+++ b/embeddedobj/test/Container1/EmbedContApp.java
@@ -564,7 +564,7 @@ public class EmbedContApp extends Applet
{
if ( m_xStorage != null && m_xEmbedObj != null )
{
- // if has persistance store there
+ // if has persistence store there
// if not it is and error, SaveAs had to be used
if ( m_bOwnFile )
@@ -1047,7 +1047,7 @@ public class EmbedContApp extends Applet
public void actionPerformed( ActionEvent e )
{
- // if has persistance store there
+ // if has persistence store there
// if not open SaveAs dialog and store
if ( m_xStorage != null && m_xEmbedObj != null )
{
diff --git a/embeddedobj/test/Container1/NativeView.java b/embeddedobj/test/Container1/NativeView.java
index 46d92dfda4d5..f4bc3647f971 100644
--- a/embeddedobj/test/Container1/NativeView.java
+++ b/embeddedobj/test/Container1/NativeView.java
@@ -48,7 +48,7 @@ public class NativeView extends java.awt.Canvas
/**
* ctor
- * Does nothing realy.
+ * Does nothing really.
* We can use our JNI mechanism for an already visible
* canvas only. So we overload the method for showing ( "setVisible()" )
* and make our intialization there. BUt we try to show an empty clean
@@ -64,8 +64,8 @@ public class NativeView extends java.awt.Canvas
// ____________________
/**
- * Overload this method to make neccessary initializations here.
- * ( e.g. get the window handle and neccessary system informations )
+ * Overload this method to make necessary initializations here.
+ * ( e.g. get the window handle and necessary system informations )
*
* Why here?
* Because the handle seams to be available for already visible windows
@@ -83,7 +83,7 @@ public class NativeView extends java.awt.Canvas
/**
* to guarantee right resize handling inside a swing container
* ( e.g. JSplitPane ) we must provide some informations about our
- * prefered/minimum and maximum size.
+ * preferred/minimum and maximum size.
*/
public Dimension getPreferredSize()
{
@@ -104,7 +104,7 @@ public class NativeView extends java.awt.Canvas
/**
* overload paint routine to show provide against
- * repaint errors if no office view is realy plugged
+ * repaint errors if no office view is really plugged
* into this canvas.
* If handle is present - we shouldn't paint anything further.
* May the remote window is already plugged. In such case we
@@ -153,7 +153,7 @@ public class NativeView extends java.awt.Canvas
// ____________________
/**
- * for using of the JNI methods it's neccessary to load
+ * for using of the JNI methods it's necessary to load
* system library which exports it.
*/
static
diff --git a/embeddedobj/test/MainThreadExecutor/xexecutor.cxx b/embeddedobj/test/MainThreadExecutor/xexecutor.cxx
index 12f37e20961b..ba0eb2f9e678 100644
--- a/embeddedobj/test/MainThreadExecutor/xexecutor.cxx
+++ b/embeddedobj/test/MainThreadExecutor/xexecutor.cxx
@@ -83,7 +83,7 @@ uno::Any SAL_CALL UNOMainThreadExecutor::execute( const uno::Sequence< beans::Na
// while( !pExecutor->isExecuted() )
// ::osl::Thread::yield();
- // TODO: implement transfering of the return values and exceptions
+ // TODO: implement transferring of the return values and exceptions
return uno::Any();
}
diff --git a/embeddedobj/source/commonembedding/persistence.cxx b/embeddedobj/source/commonembedding/persistence.cxx
index 9b64a4bd7ae3..9cc861ab67ab 100644
--- a/embeddedobj/source/commonembedding/persistence.cxx
+++ b/embeddedobj/source/commonembedding/persistence.cxx
@@ -961,13 +961,13 @@ void SAL_CALL OCommonEmbeddedObject::setPersistentEntry(
&& ( m_nObjectState == -1 || nEntryConnectionMode != embed::EntryInitModes::NO_INIT ) )
{
// if the object is not loaded
// it can not get persistant representation without initialization
// if the object is loaded
// it can switch persistant representation only without initialization
throw embed::WrongStateException(
- ::rtl::OUString::createFromAscii( "Can't change persistant representation of activated object!\n" ),
+ ::rtl::OUString::createFromAscii( "Can't change persistent representation of activated object!\n" ),
uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
}
@@ -1868,7 +1868,7 @@ void SAL_CALL OCommonEmbeddedObject::breakLink( const uno::Reference< embed::XSt
{}
m_pDocHolder->SetComponent( xDocument, m_bReadOnly );
- OSL_ENSURE( m_pDocHolder->GetComponent().is(), "If document cant be created, an exception must be thrown!\n" );
+ OSL_ENSURE( m_pDocHolder->GetComponent().is(), "If document can't be created, an exception must be thrown!\n" );
if ( m_nObjectState == embed::EmbedStates::LOADED )
{
@@ -961,13 +961,13 @@ void SAL_CALL OCommonEmbeddedObject::setPersistentEntry(
{
// if the object is not loaded
- // it can not get persistant representation without initialization
+ // it can not get persistent representation without initialization
// if the object is loaded
@@ -961,13 +961,13 @@ void SAL_CALL OCommonEmbeddedObject::setPersistentEntry(
// if the object is loaded
- // it can switch persistant representation only without initialization
+ // it can switch persistent representation only without initialization
throw embed::WrongStateException(
diff --git a/embeddedobj/source/msole/olepersist.cxx b/embeddedobj/source/msole/olepersist.cxx
index f1f36dafd586..38790e42ff76 100644
--- a/embeddedobj/source/msole/olepersist.cxx
+++ b/embeddedobj/source/msole/olepersist.cxx
@@ -1417,13 +1417,13 @@ void SAL_CALL OleEmbeddedObject::setPersistentEntry(
&& ( m_nObjectState == -1 || nEntryConnectionMode != embed::EntryInitModes::NO_INIT ) )
{
// if the object is not loaded
// it can not get persistant representation without initialization
// if the object is loaded
// it can switch persistant representation only without initialization
throw embed::WrongStateException(
- ::rtl::OUString::createFromAscii( "Can't change persistant representation of activated object!\n" ),
+ ::rtl::OUString::createFromAscii( "Can't change persistent representation of activated object!\n" ),
uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
}
@@ -1417,13 +1417,13 @@ void SAL_CALL OleEmbeddedObject::setPersistentEntry(
{
// if the object is not loaded
- // it can not get persistant representation without initialization
+ // it can not get persistent representation without initialization
// if the object is loaded
@@ -1417,13 +1417,13 @@ void SAL_CALL OleEmbeddedObject::setPersistentEntry(
// if the object is loaded
- // it can switch persistant representation only without initialization
+ // it can switch persistent representation only without initialization
throw embed::WrongStateException(